summaryrefslogtreecommitdiff
path: root/TAO/tao/default_resource.h
diff options
context:
space:
mode:
authorbala <balanatarajan@users.noreply.github.com>2002-04-30 22:15:45 +0000
committerbala <balanatarajan@users.noreply.github.com>2002-04-30 22:15:45 +0000
commit4651aa6f7eae615431888efa4f31a8309e44509f (patch)
treea3c6801f4798263e8fe0cb9d38f51f1ebb926826 /TAO/tao/default_resource.h
parent62b6092eb492d90c9c73bcd23e7ffed5087493c1 (diff)
downloadATCD-4651aa6f7eae615431888efa4f31a8309e44509f.tar.gz
ChangeLogTag: Tue Apr 30 17:03:49 2002 Balachandran Natarajan <bala@cs.wustl.edu>
Diffstat (limited to 'TAO/tao/default_resource.h')
-rw-r--r--TAO/tao/default_resource.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/TAO/tao/default_resource.h b/TAO/tao/default_resource.h
index c0c11bba5a4..627b97a0e93 100644
--- a/TAO/tao/default_resource.h
+++ b/TAO/tao/default_resource.h
@@ -113,7 +113,6 @@ public:
virtual int init_protocol_factories (void);
- virtual TAO_Resource_Factory::Caching_Strategy connection_caching_strategy_type (void) const;
virtual int cache_maximum (void) const;
virtual int purge_percentage (void) const;
virtual int max_muxed_connections (void) const;
@@ -159,9 +158,9 @@ protected:
/// list of loaded protocol factories.
TAO_ProtocolFactorySet protocol_factories_;
- /// Specifies the typeof caching strategy we should use for
- /// connection management.
- TAO_Resource_Factory::Caching_Strategy connection_caching_type_;
+ /// Specifies the typeof purging strategy we should use for cleaning
+ /// up unused connections
+ TAO_Resource_Factory::Purging_Strategy connection_purging_type_;
/// Specifies the maximum number of connections which should get cached
/// in the ORB.